require 'httparty'
require 'hashie'
require 'luma/version'
require 'luma/luma_exception'
require 'luma/connection'
require 'luma/authentication'
require 'luma/provider'
require 'luma/appointment_type'
require 'luma/facilities'

module Luma
  class Configuration
    attr_accessor :email, :password

    def initialize
      @email    = nil
      @password = nil
    end

    def api_endpoint=(endpoint)
      Connection.base_uri(endpoint.freeze)
    end

    def api_endpoint
      return Connection.base_uri
    end

    def to_h
      return {
        email: @email,
        password: @password,
        api_endpoint: api_endpoint
      }
    end

    def from_h(h)
      self.email = h[:email]
      self.password  = h[:password]
      self.api_endpoint = h[:api_endpoint]

      return self
    end
  end

  class << self
    def configuration
      @configuration ||= Configuration.new
    end

    def configure
      yield(configuration)
    end
  end

  # Luma API client
  class LumaClient
    class << self
      def connection
        @connection ||= Connection.new
      end

      def release
        @connection = nil
      end
    end
  end
end
