module Luma
  class Authentication < Connection
    attr_accessor :response, :validation_response

    BASE_ENDPOINT     = '/api'.freeze
    AUTH_ENDPOINT     = "#{BASE_ENDPOINT}/users/login".freeze
    VALIDATE_ENDPOINT = "#{BASE_ENDPOINT}/tokens/validate".freeze

    def initialize
      @response            = nil
      @validation_response = nil
    end

    def authenticate
      if (self.expires?)
        request = {
          body: { email: Luma.configuration.email, password: Luma.configuration.password },
          endpoint: AUTH_ENDPOINT
        }

        response = self.request(**request, auth: false)

        if (false == response.ok?)
          @response = nil
          raise LumaException.from_response(response, msg: 'Authentication')
        else
          @response = response
          validate
        end
      end

      return self
    end

    def validate
      request = {
        body: { token: access_token },
        endpoint: VALIDATE_ENDPOINT
      }

      response = self.request(**request, auth: false)

      if (false == response.ok?)
        @response = nil
        raise LumaException.from_response(response, msg: 'Authentication Validation')
      else
        @validation_response = response
      end
    end

    def access_token
      return @response['token'] if @response
    end

    def expiry
      return @validation_response['exp'] if @validation_response
    end

    def expires?
      if (self.expiry)
        return self.expiry <= (Time.now.to_f * 1000).floor
      else
        return true
      end
    end

    def access_header
      return {
        'X-Access-Token' => self.access_token,
      }
    end

    def expire!
      @response = nil
    end
  end
end
