module Luma
  class Connection
    DEFAULT_ENDPOINT = '/endpoint'.freeze

    include HTTParty

    base_uri 'https://api.lumahealth.io/'.freeze

    headers 'Content-Type' => 'application/json'

    format :json

    def initialize(body: nil, headers: {})
      @body = body
      @headers = headers
    end

    def request(endpoint: DEFAULT_ENDPOINT, body: nil, headers: {}, auth: true, verb: :post)
      body    = body.to_json if body.is_a?(Hash)
      headers = auth_header.merge(headers) if auth

      self.class.send("#{verb}", endpoint, body: body, headers: headers)
    end

    def add_headers_and_body
      @body = @body.to_json
      @headers = auth_header.merge(@headers)
      @headers["Content-Type"] = 'application/json'
    end

    private

    def auth_header
      @auth ||= Authentication.new

      return @auth.authenticate.access_header
    end
  end
end
